#!/bin/bash

##
# install.sh is the gcc-prebuilt installer for running by npm. It asks the user
# for '--prefix' as the top installation directory and installs gcc-prebuilt by 
# copying its files to their destinations.Upon successful installation, a '~/.gcc-prebuilt/config' file
# is stored. This file is needed by gcc-prebuilt uninstall.sh in order to remove the installed gcc-prebuilt
# archives and binaries correctly.
#
# user can choose one of the following as the prefix to install the gcc-prebuilt:
#
#   0) $HOME
#   1) $HOME/.local
#   2) /usr/local (require root privileges)
#
##

#
# Copyright (C) 2016 Mawni Maghsoudlou
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/.
#
##

set -e

gcc_preb_url="https://github.com/mawni/gcc-prebuilt/releases/download/v1.0.3/gcc-6.1.0-linux-gnu-x86_64-prebuilt.tar.xz"
config_dir="$HOME/.gcc-prebuilt"
gcc_preb_tar="$config_dir/gcc-6.1.0-linux-gnu-x86_64-prebuilt.tar.xz"
gcc_preb_untar="$config_dir/gcc-6.1.0-linux-gnu-x86_64-prebuilt"

mkdir -pv $config_dir
if [[ -f $gcc_preb_tar ]]; then  
  cd $config_dir
  echo -e "\ngcc-prebuilt: Extracting $gcc_preb_tar \n"
  tar xvf $gcc_preb_tar
  cd $gcc_preb_untar && ./install.sh
else
  {
    cd $config_dir
    echo -e "\ngcc-prebuilt: Downloading $gcc_preb_tar from $gcc_preb_url \n"
    wget $gcc_preb_url
    echo -e "\ngcc-prebuilt: Extracting $gcc_preb_tar \n"
    tar xvf $gcc_preb_tar
  } 2>&1 | tee ~/.gcc-prebuilt/download.log
  cd $gcc_preb_untar && ./install.sh
fi

