#!/bin/bash

##
# uninstall.sh is the gcc-prebuilt uninstaller for running by npm.
# It removes gcc-prebuilt archives and binaries from the install directory 
# as well as gcc-prebuilt install files. It gets the install directory by 
# reading the '~/.gcc-prebuilt/config' is saved when gcc-prebuilt is installed.
#
##

##
# Copyright (C) 2016 Mawni Maghsoudlou
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/.
#
##

set -e

config_dir="$HOME/.gcc-prebuilt"
config="$config_dir/config"
prefix=$(<$config)
home="$HOME"
home_local="$HOME/.local"
usr_local="/usr/local"
gcc_ver="gcc-6.1.0"

rm_empty_dir () {
  if [[ $1 == $usr_local ]]; then
    sudo find $1/lib/gcc -type d -empty -delete
    sudo find $1/share/man/man1 -type d -empty -delete
    sudo find $1/share/man/man7 -type d -empty -delete
  else
    find $1/lib/gcc -type d -empty -delete
    find $1/share/man/man1 -type d -empty -delete
    find $1/share/man/man7 -type d -empty -delete
  fi
}

if [[ $prefix == $home || $prefix == $home_local ]]; then
  echo -e "\ngcc-prebuilt: Removing $gcc_ver archives and binaries from $prefix"
  rm -rfv $prefix/bin/{c++,cpp,g++,gcc,gcc-ar,gccgo,gcc-nm,gcc-ranlib,gcov,gcov-tool,gfortran,go,gofmt,x86_64-linux-gnu-c++,x86_64-linux-gnu-g++,x86_64-linux-gnu-gcc,x86_64-linux-gnu-gcc-6.1.0,x86_64-linux-gnu-gcc-ar,x86_64-linux-gnu-gccgo,x86_64-linux-gnu-gcc-nm,x86_64-linux-gnu-gcc-ranlib,x86_64-linux-gnu-gfortran}
  rm -rfv $prefix/include/c++
  rm -rfv $prefix/lib/gcc/x86_64-linux-gnu/6.1.0
  rm -rfv $prefix/lib64
  rm -rfv $prefix/share/{gcc-6.1.0,info,locale}
  rm -rfv $prefix/share/man/man1/{cpp.1,g++.1,gcc.1,gccgo.1,gcov.1,gfortran.1,go.1,gofmt.1}
  rm -rfv $prefix/share/man/man7/{fsf-funding.7,gfdl.7,gpl.7}
  rm_empty_dir $prefix
  echo -e "\ngcc-prebuilt: Removing gcc-prebuilt config files"
  rm -rfv $config_dir
  echo -e "\ngcc-prebuilt: $gcc_ver archives and binaries removed from $prefix successfully.\n"

elif [[ $prefix == $usr_local ]]; then
  echo -e "\ngcc-prebuilt: Removing $gcc_ver archives and binaries from $prefix"
  sudo rm -rfv $prefix/bin/{c++,cpp,g++,gcc,gcc-ar,gccgo,gcc-nm,gcc-ranlib,gcov,gcov-tool,gfortran,go,gofmt,x86_64-linux-gnu-c++,x86_64-linux-gnu-g++,x86_64-linux-gnu-gcc,x86_64-linux-gnu-gcc-6.1.0,x86_64-linux-gnu-gcc-ar,x86_64-linux-gnu-gccgo,x86_64-linux-gnu-gcc-nm,x86_64-linux-gnu-gcc-ranlib,x86_64-linux-gnu-gfortran}
  sudo rm -rfv $prefix/include/c++
  sudo rm -rfv $prefix/lib/gcc/x86_64-linux-gnu/6.1.0
  sudo rm -rfv $prefix/lib64
  sudo rm -rfv $prefix/share/{gcc-6.1.0,info,locale}
  sudo rm -rfv $prefix/share/man/man1/{cpp.1,g++.1,gcc.1,gccgo.1,gcov.1,gfortran.1,go.1,gofmt.1}
  sudo rm -rfv $prefix/share/man/man7/{fsf-funding.7,gfdl.7,gpl.7}
  rm_empty_dir $prefix
  echo -e "\ngcc-prebuilt: Removing gcc-prebuilt config files"
  rm -rfv $config_dir
  echo -e "\ngcc-prebuilt: $gcc_ver archives and binaries removed from $prefix successfully.\n"
else
  echo -e "gcc-prebuilt: prefix not found."
  exit
fi

